@@ -35,12 +35,13 @@ def in_devel():
 
 LIBDIR = '/usr/lib'
 PKGDATADIR = '/usr/share/pitivi'
-GITVERSION = '0.96'
-VERSION = '0.96'
+GITVERSION = ''
+VERSION = '0.97.1'
 APPNAME = 'Pitivi'
 APPURL = 'http://www.pitivi.org/'
 RELEASES_URL = 'http://pitivi.org/releases.txt'
 APPMANUALURL_ONLINE = 'http://www.pitivi.org/manual'
+BUILDDIR = '/build/pitivi/src/pitivi-0.97.1/mesonbuild'
 
 
 if in_devel():
