@@ -37,13 +37,13 @@ from pitivi.configure import get_pixmap_dir
 from pitivi.configure import get_ui_dir
 from pitivi.configure import GITVERSION
 from pitivi.configure import in_devel
+from pitivi.configure import VERSION
 from pitivi.dialogs.prefs import PreferencesDialog
 from pitivi.effects import EffectListWidget
 from pitivi.mediafilespreviewer import PreviewWidget
 from pitivi.medialibrary import MediaLibraryWidget
 from pitivi.project import ProjectSettingsDialog
 from pitivi.settings import GlobalSettings
-from pitivi.shortcutswindow import ShortcutsWindow
 from pitivi.tabsmanager import BaseTabs
 from pitivi.timeline.timeline import TimelineContainer
 from pitivi.titleeditor import TitleEditor
@@ -176,9 +176,6 @@ class MainWindow(Gtk.ApplicationWindow, Loggable):
 
         project = self.app.project_manager.current_project
         dialog = RenderDialog(self.app, project)
-        dialog.window.connect("destroy", self._renderDialogDestroyCb)
-        self.set_sensitive(False)
-        self.timeline_ui.disableKeyboardAndMouseEvents()
         dialog.window.show()
 
     def _destroyedCb(self, unused_self):
@@ -207,10 +204,6 @@ class MainWindow(Gtk.ApplicationWindow, Loggable):
         self.vpaned.remove(self.timeline_ui)
         self.timeline_ui.destroy()
 
-    def _renderDialogDestroyCb(self, unused_dialog):
-        self.set_sensitive(True)
-        self.timeline_ui.enableKeyboardAndMouseEvents()
-
     def _renderCb(self, unused_button):
         self.showRenderDialog()
 
@@ -444,46 +437,52 @@ class MainWindow(Gtk.ApplicationWindow, Loggable):
         self._headerbar.pack_start(self.render_button)
 
     def _set_keyboard_shortcuts(self):
-        ShortcutsWindow.register_group("win", _("Project"))
+        self.app.shortcuts.register_group("win", _("Project"))
         self.save_action = Gio.SimpleAction.new("save", None)
         self.save_action.connect("activate", self._saveProjectCb)
         self.add_action(self.save_action)
-        self.app.set_accels_for_action("win.save", ["<Control>s"])
+        self.app.shortcuts.add("win.save", ["<Control>s"],
+                               _("Save the current project"))
         self.save_button.set_action_name("win.save")
-        ShortcutsWindow.add_action("win.save", _("Save the current project"))
 
         self.new_project_action = Gio.SimpleAction.new("new-project", None)
         self.new_project_action.connect("activate", self._newProjectMenuCb)
         self.add_action(self.new_project_action)
-        self.app.set_accels_for_action("win.new-project", ["<Control>n"])
-        ShortcutsWindow.add_action("win.new-project", _("Create a new project"))
+        self.app.shortcuts.add("win.new-project", ["<Control>n"],
+                               _("Create a new project"))
 
         self.open_project_action = Gio.SimpleAction.new("open-project", None)
         self.open_project_action.connect("activate", self._openProjectCb)
         self.add_action(self.open_project_action)
-        self.app.set_accels_for_action("win.open-project", ["<Control>o"])
-        ShortcutsWindow.add_action("win.open-project", _("Open a project"))
+        self.app.shortcuts.add("win.open-project", ["<Control>o"],
+                               _("Open a project"))
 
         self.save_as_action = Gio.SimpleAction.new("save-as", None)
         self.save_as_action.connect("activate", self._saveProjectAsCb)
         self.add_action(self.save_as_action)
-        self.app.set_accels_for_action("win.save-as", ["<Control><Shift>s"])
-        ShortcutsWindow.add_action("win.save-as",
-                                   _("Save the current project as"))
+        self.app.shortcuts.add("win.save-as", ["<Control><Shift>s"],
+                               _("Save the current project as"))
 
         self.help_action = Gio.SimpleAction.new("help", None)
         self.help_action.connect("activate", self._userManualCb)
         self.add_action(self.help_action)
-        self.app.set_accels_for_action("win.help", ["F1"])
-        ShortcutsWindow.add_action("win.help", _("Help"), group="app")
+        self.app.shortcuts.add("win.help", ["F1"], _("Help"), group="app")
 
         self.menu_button_action = Gio.SimpleAction.new("menu-button", None)
         self.menu_button_action.connect("activate", self._menuCb)
         self.add_action(self.menu_button_action)
-        self.app.set_accels_for_action("win.menu-button", ["F10"])
-        ShortcutsWindow.add_action("win.menu-button",
-                                   _("Show the menu button content"),
-                                   group="app")
+        self.app.shortcuts.add("win.menu-button", ["F10"],
+                               _("Show the menu button content"),
+                               group="app")
+
+        import_asset_action = Gio.SimpleAction.new("import-asset", None)
+        import_asset_action.connect("activate", self.__import_asset_cb)
+        self.add_action(import_asset_action)
+        self.app.shortcuts.add("win.import-asset", ["<Control>i"],
+                               _("Add media files to your project"))
+
+    def __import_asset_cb(self, unusdaction, unusedparam):
+        self.medialibrary.show_import_assets_dialog()
 
     def showProjectStatus(self):
         project = self.app.project_manager.current_project
@@ -611,8 +610,10 @@ class MainWindow(Gtk.ApplicationWindow, Loggable):
             version_str = _("Version %(cur_ver)s — %(new_ver)s is available" %
                             {"cur_ver": GITVERSION,
                              "new_ver": self.app.getLatest()})
-        else:
+        elif GITVERSION:
             version_str = _("Version %s" % GITVERSION)
+        else:
+            version_str = _("Version %s" % VERSION)
         abt.set_version(version_str)
 
         comments = ["",
