@@ -31,7 +31,6 @@ from pitivi.autoaligner import AutoAligner
 from pitivi.configure import get_ui_dir
 from pitivi.dialogs.prefs import PreferencesDialog
 from pitivi.settings import GlobalSettings
-from pitivi.shortcutswindow import ShortcutsWindow
 from pitivi.timeline.elements import Clip
 from pitivi.timeline.elements import TransitionClip
 from pitivi.timeline.elements import TrimHandle
@@ -84,7 +83,7 @@ GlobalSettings.addConfigOption('imageClipLength',
                                notify=True)
 
 PreferencesDialog.addNumericPreference('imageClipLength',
-                                       section=_("timeline"),
+                                       section="timeline",
                                        label=_("Image clip duration"),
                                        description=_(
                                            "Default clip length (in milliseconds) of images when inserting on the timeline."),
@@ -97,7 +96,7 @@ GlobalSettings.addConfigOption('leftClickAlsoSeeks',
                                notify=True)
 
 PreferencesDialog.addTogglePreference('leftClickAlsoSeeks',
-                                      section=_("timeline"),
+                                      section="timeline",
                                       label=_("Left click also seeks"),
                                       description=_(
                                           "Whether left-clicking also seeks besides selecting and editing clips."))
@@ -1307,6 +1306,11 @@ class TimelineContainer(Gtk.Grid, Zoomable, Loggable):
         can_paste = bool(self.__copiedGroup)
         self.paste_action.set_enabled(can_paste)
         self.keyframe_action.set_enabled(selection_non_empty)
+        project_loaded = bool(self._project)
+        self.backward_one_frame_action.set_enabled(project_loaded)
+        self.forward_one_frame_action.set_enabled(project_loaded)
+        self.backward_one_second_action.set_enabled(project_loaded)
+        self.forward_one_second_action.set_enabled(project_loaded)
 
     # Internal API
 
@@ -1357,18 +1361,6 @@ class TimelineContainer(Gtk.Grid, Zoomable, Loggable):
 
         self.show_all()
 
-    def enableKeyboardAndMouseEvents(self):
-        self.info("Unblocking timeline mouse and keyboard signals")
-        self.timeline.disconnect_by_func(self._ignoreAllEventsCb)
-
-    def disableKeyboardAndMouseEvents(self):
-        """A safety measure to prevent interacting with the timeline."""
-        self.info("Blocking timeline mouse and keyboard signals")
-        self.timeline.connect("event", self._ignoreAllEventsCb)
-
-    def _ignoreAllEventsCb(self, *unused_args):
-        return True
-
     def _getLongestLayer(self):
         """Returns the longest layer."""
         layers = self.ges_timeline.get_layers()
@@ -1383,7 +1375,7 @@ class TimelineContainer(Gtk.Grid, Zoomable, Loggable):
         return longest_layer
 
     def _createActions(self):
-        # The actions below are all added to this action group and they
+        # The actions below are added to this action group and thus
         # are accessible only to the self.timeline.layout and self.toolbar
         # widgets (and their children) using the "timeline" prefix.
         # When the action for an accelerator is searched, due to the "timeline"
@@ -1393,94 +1385,111 @@ class TimelineContainer(Gtk.Grid, Zoomable, Loggable):
         group = Gio.SimpleActionGroup()
         self.timeline.layout.insert_action_group("timeline", group)
         self.toolbar.insert_action_group("timeline", group)
-        ShortcutsWindow.register_group("timeline", _("Timeline"))
-
-        self.zoom_in_action = Gio.SimpleAction.new("zoom-in", None)
-        self.zoom_in_action.connect("activate", self._zoomInCb)
-        group.add_action(self.zoom_in_action)
-        self.app.set_accels_for_action("timeline.zoom-in", ["<Control>plus",
-                                                            "<Control>equal"])
-        ShortcutsWindow.add_action("timeline.zoom-in", _("Zoom in"))
-
-        self.zoom_out_action = Gio.SimpleAction.new("zoom-out", None)
-        self.zoom_out_action.connect("activate", self._zoomOutCb)
-        group.add_action(self.zoom_out_action)
-        self.app.set_accels_for_action("timeline.zoom-out", ["<Control>minus"])
-        ShortcutsWindow.add_action("timeline.zoom-out", _("Zoom out"))
-
-        self.zoom_fit_action = Gio.SimpleAction.new("zoom-fit", None)
-        self.zoom_fit_action.connect("activate", self._zoomFitCb)
-        group.add_action(self.zoom_fit_action)
-        self.app.set_accels_for_action("timeline.zoom-fit", ["<Control>0"])
-        ShortcutsWindow.add_action("timeline.zoom-fit",
-                                   _("Adjust zoom to fit the project to the window"))
+        self.app.shortcuts.register_group("timeline", _("Timeline"))
 
         # Clips actions.
         self.delete_action = Gio.SimpleAction.new("delete-selected-clips", None)
         self.delete_action.connect("activate", self._deleteSelected)
         group.add_action(self.delete_action)
-        self.app.set_accels_for_action("timeline.delete-selected-clips",
-                                       ["Delete"])
-        ShortcutsWindow.add_action("timeline.delete-selected-clips",
-                                   _("Delete selected clips"))
+        self.app.shortcuts.add("timeline.delete-selected-clips", ["Delete"],
+                               _("Delete selected clips"))
 
         self.group_action = Gio.SimpleAction.new("group-selected-clips", None)
         self.group_action.connect("activate", self._groupSelected)
         group.add_action(self.group_action)
-        self.app.set_accels_for_action("timeline.group-selected-clips",
-                                       ["<Control>g"])
-        ShortcutsWindow.add_action("timeline.group-selected-clips",
-                                   _("Group selected clips together"))
+        self.app.shortcuts.add("timeline.group-selected-clips", ["<Control>g"],
+                               _("Group selected clips together"))
 
         self.ungroup_action = Gio.SimpleAction.new("ungroup-selected-clips", None)
         self.ungroup_action.connect("activate", self._ungroupSelected)
         group.add_action(self.ungroup_action)
-        self.app.set_accels_for_action("timeline.ungroup-selected-clips",
-                                       ["<Shift><Control>g"])
-        ShortcutsWindow.add_action("timeline.ungroup-selected-clips",
-                                   _("Ungroup selected clips"))
+        self.app.shortcuts.add("timeline.ungroup-selected-clips", ["<Shift><Control>g"],
+                               _("Ungroup selected clips"))
 
         self.copy_action = Gio.SimpleAction.new("copy-selected-clips", None)
         self.copy_action.connect("activate", self.__copyClipsCb)
         group.add_action(self.copy_action)
-        self.app.set_accels_for_action("timeline.copy-selected-clips",
-                                       ["<Control>c"])
-        ShortcutsWindow.add_action("timeline.copy-selected-clips",
-                                   _("Copy selected clips"))
+        self.app.shortcuts.add("timeline.copy-selected-clips", ["<Control>c"],
+                               _("Copy selected clips"))
 
         self.paste_action = Gio.SimpleAction.new("paste-clips", None)
         self.paste_action.connect("activate", self.__pasteClipsCb)
         group.add_action(self.paste_action)
-        self.app.set_accels_for_action("timeline.paste-clips", ["<Control>v"])
-        ShortcutsWindow.add_action("timeline.paste-clips",
-                                   _("Paste selected clips"))
+        self.app.shortcuts.add("timeline.paste-clips", ["<Control>v"],
+                               _("Paste selected clips"))
 
         self.gapless_action = Gio.SimpleAction.new("toggle-gapless-mode", None)
         self.gapless_action.connect("activate", self._gaplessmodeToggledCb)
         group.add_action(self.gapless_action)
 
         # Playhead actions.
-        self.play_action = Gio.SimpleAction.new("play", None)
-        self.play_action.connect("activate", self._playPauseCb)
-        group.add_action(self.play_action)
-        self.app.set_accels_for_action("timeline.play", ["space"])
-        ShortcutsWindow.add_action("timeline.play", _("Play"))
-
         self.split_action = Gio.SimpleAction.new("split-clips", None)
         self.split_action.connect("activate", self._splitCb)
         group.add_action(self.split_action)
-        self.app.set_accels_for_action("timeline.split-clips", ["S"])
         self.split_action.set_enabled(True)
-        ShortcutsWindow.add_action("timeline.split-clips",
-                                   _("Split the clip at the position"))
+        self.app.shortcuts.add("timeline.split-clips", ["S"],
+                               _("Split the clip at the position"))
 
         self.keyframe_action = Gio.SimpleAction.new("keyframe-selected-clips", None)
         self.keyframe_action.connect("activate", self._keyframe_cb)
         group.add_action(self.keyframe_action)
-        self.app.set_accels_for_action("timeline.keyframe-selected-clips",
-                                       ["K"])
-        ShortcutsWindow.add_action("timeline.keyframe-selected-clips",
-                                   _("Add keyframe to the keyframe curve of selected clip"))
+        self.app.shortcuts.add("timeline.keyframe-selected-clips", ["K"],
+                               _("Add keyframe to the keyframe curve of selected clip"))
+
+        navigation_group = Gio.SimpleActionGroup()
+        self.timeline.layout.insert_action_group("navigation", navigation_group)
+        self.toolbar.insert_action_group("navigation", navigation_group)
+        self.app.shortcuts.register_group("navigation", _("Timeline Navigation"))
+
+        self.zoom_in_action = Gio.SimpleAction.new("zoom-in", None)
+        self.zoom_in_action.connect("activate", self._zoomInCb)
+        navigation_group.add_action(self.zoom_in_action)
+        self.app.shortcuts.add("navigation.zoom-in",
+                               ["<Control>plus", "<Control>equal"],
+                               _("Zoom in"))
+
+        self.zoom_out_action = Gio.SimpleAction.new("zoom-out", None)
+        self.zoom_out_action.connect("activate", self._zoomOutCb)
+        navigation_group.add_action(self.zoom_out_action)
+        self.app.shortcuts.add("navigation.zoom-out", ["<Control>minus"],
+                               _("Zoom out"))
+
+        self.zoom_fit_action = Gio.SimpleAction.new("zoom-fit", None)
+        self.zoom_fit_action.connect("activate", self._zoomFitCb)
+        navigation_group.add_action(self.zoom_fit_action)
+        self.app.shortcuts.add("navigation.zoom-fit", ["<Control>0"],
+                               _("Adjust zoom to fit the project to the window"))
+
+        self.play_action = Gio.SimpleAction.new("play", None)
+        self.play_action.connect("activate", self._playPauseCb)
+        navigation_group.add_action(self.play_action)
+        self.app.shortcuts.add("navigation.play", ["space"], _("Play"))
+
+        self.backward_one_frame_action = Gio.SimpleAction.new("backward_one_frame", None)
+        self.backward_one_frame_action.connect("activate", self._seek_backward_one_frame_cb)
+        navigation_group.add_action(self.backward_one_frame_action)
+        self.app.shortcuts.add("navigation.backward_one_frame", ["Left"],
+                               _("Seek backward one frame"))
+
+        self.forward_one_frame_action = Gio.SimpleAction.new("forward_one_frame", None)
+        self.forward_one_frame_action.connect("activate", self._seek_forward_one_frame_cb)
+        navigation_group.add_action(self.forward_one_frame_action)
+        self.app.shortcuts.add("navigation.forward_one_frame", ["Right"],
+                               _("Seek forward one frame"))
+
+        self.backward_one_second_action = Gio.SimpleAction.new("backward_one_second", None)
+        self.backward_one_second_action.connect("activate", self._seek_backward_one_second_cb)
+        navigation_group.add_action(self.backward_one_second_action)
+        self.app.shortcuts.add("navigation.backward_one_second",
+                               ["<Shift>Left"],
+                               _("Seek backward one second"))
+
+        self.forward_one_second_action = Gio.SimpleAction.new("forward_one_second", None)
+        self.forward_one_second_action.connect("activate", self._seek_forward_one_second_cb)
+        navigation_group.add_action(self.forward_one_second_action)
+        self.app.shortcuts.add("navigation.forward_one_second",
+                               ["<Shift>Right"],
+                               _("Seek forward one second"))
 
     def _setBestZoomRatio(self, allow_zoom_in=False):
         """Sets the zoom level so that the entire timeline is in view."""
@@ -1730,30 +1739,28 @@ class TimelineContainer(Gtk.Grid, Zoomable, Loggable):
         elif event.keyval == Gdk.KEY_Control_L:
             self._controlMask = True
 
-        # Now the second (independent) part: framestepping and seeking
-        # shortcuts
-        if event.keyval == Gdk.KEY_Left:
-            if self._shiftMask:
-                self._project.pipeline.seekRelative(0 - Gst.SECOND)
-            else:
-                self._project.pipeline.stepFrame(self._framerate, -1)
-            self.timeline.scrollToPlayhead(align=Gtk.Align.CENTER, when_not_in_view=True)
-            return True
-        elif event.keyval == Gdk.KEY_Right:
-            if self._shiftMask:
-                self._project.pipeline.seekRelative(Gst.SECOND)
-            else:
-                self._project.pipeline.stepFrame(self._framerate, 1)
-            self.timeline.scrollToPlayhead(align=Gtk.Align.CENTER, when_not_in_view=True)
-            return True
-        return False
-
     def do_key_release_event(self, event):
         if event.keyval == Gdk.KEY_Shift_L:
             self._shiftMask = False
         elif event.keyval == Gdk.KEY_Control_L:
             self._controlMask = False
 
+    def _seek_backward_one_second_cb(self, unused_action, unused_parameter):
+        self._project.pipeline.seekRelative(0 - Gst.SECOND)
+        self.timeline.scrollToPlayhead(align=Gtk.Align.CENTER, when_not_in_view=True)
+
+    def _seek_forward_one_second_cb(self, unused_action, unused_parameter):
+        self._project.pipeline.seekRelative(Gst.SECOND)
+        self.timeline.scrollToPlayhead(align=Gtk.Align.CENTER, when_not_in_view=True)
+
+    def _seek_backward_one_frame_cb(self, unused_action, unused_parameter):
+        self._project.pipeline.stepFrame(self._framerate, -1)
+        self.timeline.scrollToPlayhead(align=Gtk.Align.CENTER, when_not_in_view=True)
+
+    def _seek_forward_one_frame_cb(self, unused_action, unused_parameter):
+        self._project.pipeline.stepFrame(self._framerate, 1)
+        self.timeline.scrollToPlayhead(align=Gtk.Align.CENTER, when_not_in_view=True)
+
     def do_focus_in_event(self, unused_event):
         self.log("Timeline has grabbed focus")
         self.updateActions()
